@@ -1,9 +1,10 @@
 # <@LICENSE>
-# Copyright 2004 Apache Software Foundation
-# 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to you under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at:
 # 
 #     http://www.apache.org/licenses/LICENSE-2.0
 # 
@@ -46,12 +47,13 @@ the learning process.
 package Mail::SpamAssassin::PerMsgLearner;
 
 use strict;
+use warnings;
 use bytes;
 
 use Mail::SpamAssassin;
-use Mail::SpamAssassin::AutoWhitelist;
 use Mail::SpamAssassin::PerMsgStatus;
 use Mail::SpamAssassin::Bayes;
+use Mail::SpamAssassin::Logger;
 
 use vars qw{
   @ISA
@@ -96,9 +98,10 @@ sub new {
 sub learn_spam {
   my ($self, $id) = @_;
 
-  if ($self->{main}->{learn_with_whitelist}) {
-    $self->{main}->add_all_addresses_to_blacklist ($self->{msg});
-  }
+  # bug 4096
+  # if ($self->{main}->{learn_with_whitelist}) {
+  # $self->{main}->add_all_addresses_to_blacklist ($self->{msg});
+  # }
 
   # use the real message-id here instead of mass-check's idea of an "id",
   # as we may deliver the msg into another mbox format but later need
@@ -122,9 +125,10 @@ sub learn_spam {
 sub learn_ham {
   my ($self, $id) = @_;
 
-  if ($self->{main}->{learn_with_whitelist}) {
-    $self->{main}->add_all_addresses_to_whitelist ($self->{msg});
-  }
+  # bug 4096
+  # if ($self->{main}->{learn_with_whitelist}) {
+  # $self->{main}->add_all_addresses_to_whitelist ($self->{msg});
+  # }
 
   $self->{learned} = $self->{bayes_scanner}->learn (0, $self->{msg}, $id);
 }
@@ -145,9 +149,10 @@ sub learn_ham {
 sub forget {
   my ($self, $id) = @_;
 
-  if ($self->{main}->{learn_with_whitelist}) {
-    $self->{main}->remove_all_addresses_from_whitelist ($self->{msg});
-  }
+  # bug 4096
+  # if ($self->{main}->{learn_with_whitelist}) {
+  # $self->{main}->remove_all_addresses_from_whitelist ($self->{msg});
+  # }
 
   $self->{learned} = $self->{bayes_scanner}->forget ($self->{msg}, $id);
 }
@@ -175,18 +180,11 @@ Finish with the object.
 
 sub finish {
   my $self = shift;
-  delete $self->{main};
-  delete $self->{msg};
-  delete $self->{conf};
-  delete $self->{bayes_scanner};
+  %{$self} = ();
 }
 
 ###########################################################################
 
-sub dbg { Mail::SpamAssassin::dbg (@_); }
-
-###########################################################################
-
 1;
 __END__
 
